import os
import argparse
from .setup_binaries import setup

parser = argparse.ArgumentParser()

parser.add_argument("-S", "--setup", dest="setup", help="Setup IRS",
                    action="store_true")

args, unknown = parser.parse_known_args()

if args.setup:
    setup()
    exit(0)
elif not os.path.isdir(os.path.expanduser("~/.irs")):
    print("Please run `irs --setup` to install the youtube-dl and \
ffmpeg binaries.")
    exit(1)
else:
    from .ripper import Ripper
    Ripper



import sys
from os import path

if path.isfile(path.expanduser("~/.irs/config_.py")):
    sys.path.append(path.expanduser("~/.irs"))  # Add config to path

    import config_  # from "~/.irs/config_.py"

    CONFIG = config_.CONFIG
else:
    config = open("irs/config_preset.py", "r").read()
    CONFIG = eval(config)



import ydl_binaries
from shutil import copyfile
import os
import inspect
import irs


def setup():
    bin_path = os.path.expanduser("~/.irs/bin/")

    ydl_binaries.download_ffmpeg(bin_path)
    ydl_binaries.update_ydl(bin_path)

    config_file = os.path.expanduser("~/.irs/config_.py")
    if not os.path.isfile(config_file):
        copyfile(os.path.dirname(inspect.getfile(irs)) + "/config_preset.py",
                 config_file)
